RifGenSrc

Struct RifGenSrc 

pub struct RifGenSrc {
    pub top: RifGenTop,
    pub rifs: HashMap<String, Rif>,
    pub rifmux: HashMap<String, Rifmux>,
    pub paths: HashMap<String, PathBuf>,
    /* private fields */
}
Source RIF Generator (result of parsing)

Fields

top: RifGenTop

Top level

rifs: HashMap<String, Rif>

Dictionary of all rif definitions parsed

rifmux: HashMap<String, Rifmux>

Dictionary of all rifmux parsed

paths: HashMap<String, PathBuf>

Path of each rif/rifmux

Implementations

Source

impl RifGenSrc

pub fn new() -> RifGenSrc

pub fn from_file<P>( filename: P, includes: &[String], cfg: &ParserCfg, ) -> Result<RifGenSrc, RifError>
where P: AsRef<Path>,

Generate a source object from a file the includes path are used to find and parse any included/referenced RIF The configuration contains list of reserved keywords and how they should be handled, as well as as setting such as auto-legacy

pub fn parse_file<P>( &mut self, filename: P, cfg: &ParserCfg, ) -> Result<HashSet<String>, RifError>
where P: AsRef<Path>,

pub fn get_rif<'a>(&'a self, name: &'a str) -> Option<&'a Rif>

pub fn get_rifmux<'a>(&'a self, name: &'a str) -> Option<&'a Rifmux>

pub fn check_reg_uniq(&self, name: &str) -> bool

Check that a register is uniquely defined